@@ -13,14 +13,14 @@ use XML::Simple;
 use Time::HiRes;
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our $DEFAULT_CHUNK = 250;
 our $DEFAULT_DV = 0;
 
 =head1 NAME
 
-ServiceNow::SOAP - A better perl API for ServiceNow
+ServiceNow::SOAP - A better Perl API for ServiceNow
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,7 @@ Insert a record.
 
 Retrieve a single record based on sys_id.
 
-    my $rec = $incident_tbl->get(sys_id => $sys_id);
+    my $rec = $incident_tbl->get($sys_id);
     print "number=", $rec->{number}, "\n";
 
 Retrieve a single record based on number.
@@ -123,8 +123,7 @@ Retrieve a single record based on number.
     
 Update a record.
 
-    $incident_tbl->update(
-        sys_id => $sys_id,
+    $incident_tbl->update($sys_id,
         assigned_to => "Fred Luddy",
         incident_state => 2);
     
@@ -742,7 +741,7 @@ the result excludes all columns except sys_id, number and description.
 
     my $incident = $sn->table("incident");
     my @recs = $incident->getRecords(
-        __encoded_query => "sys_created_on>=$datetime,
+        __encoded_query => "sys_created_on>=$datetime",
         __exclude_columns => 
             $incident->except("sys_id,number,description"),
         __limit => 250);
@@ -984,7 +983,6 @@ sub insert {
 =head2 insertMultiple
 
 This method inserts multiple records.
-
 The input is an array of hash references.
 It returns an array of hash references.
 
@@ -1094,13 +1092,13 @@ by calling L</getKeys>.
 B<Syntax>
 
     my $query = $table->query(%parameters);
-    my $query = $table->query($encodedquery};
+    my $query = $table->query($encodedquery);
     
 B<Example>
 
 The following example builds a list of all Incidents 
 created between 1/1/2014 and 2/1/2014 sorted by creation date/time.
-The C<fetchAll> method fetches chunks of records 
+The L</fetchAll> method fetches chunks of records 
 until all records have been retrieved.
 
     my $filter = "sys_created_on>=2014-01-01^sys_created_on<2014-02-01";
@@ -1555,7 +1553,7 @@ B<Syntax>
     
 B<Example>
 
-This example returns a list of all records in the B<cmdb_ci_computer> table,
+This example returns a list of all records in the C<cmdb_ci_computer> table,
 but only 5 columns are returnd.
 
     my $tbl = $sn->table("cmdb_ci_computer");
@@ -1580,7 +1578,7 @@ This method sets the default chunk size
 for subsequent calls to L</fetch> or L</fetchAll>.
 It returns a reference to the modified Query object.
 
-If B<setChunk> is not specified then 
+If C<setChunk> is not specified then 
 the default is 250 records per fetch.
 
 B<Syntax>
@@ -1615,21 +1613,23 @@ sub setIndex {
 
 =head1 DIAGNOSTICS
 
-The fourth (optional) argument to the L</ServiceNow> function is an integer trace level
-which can be helpful for debugging.
+The fourth (optional) argument to the L</ServiceNow> function 
+is an integer trace level which can be helpful for debugging.
 Sometimes, when you are developing a new script,
-it seems to hang at a certain point, and you just want to know what it is doing.
-Set the trace level to 1 to enable tracing messages for SOAP calls.
-Set the trace level to 2 to dump the complete XML of all SOAP results.
+it seems to hang at a certain point, 
+and you just want to know what it is doing.
+Set the trace level to 1 to print a single line for each Web Services call.
+Set the trace level to 2 to print the complete XML result for each call.
 Set the trace level to 0 (default) to disable this feature.
 
-You can also enable or disable tracing for a table by calling C<setTrace> on the object.
+You can also enable or disable tracing for a table by 
+calling C<setTrace> on the object.
 
     $table->setTrace(2);
     
 If you want even more, then add the following to your code.
 This will cause SOAP:Lite to dump the HTTP headers
-and contens for all messages, both sent and received.
+and contents for all messages, both sent and received.
 
     SOAP::Lite->import(+trace => 'debug');
 
